# Saranphat Roungkitrakran

Hello Guy, Myname is Saranphat Roungkitrakran. Iwill explain about this module

  - Show about my profile
  - Show my name in Thai and Japanese


### How to install 

If you already installed python.You can use command prompt or python shell and use command 'pip'

```sh
pip install saranphat
```

Alright. After installed my module , you can use my module now.

How to use 
- Open your python project and write by following this script
```sh
from sanphat import Saranphat

mystatus = Saranphat()
    print(mystatus)
    mystatus.thainame()
    mystatus.japanname()
    mystatus.WhatAmI()
```

### Contract us

You can contract me by following list:

| Topic | Link |
| ------ | ------ |
| E-mail |Gungungungundam@hotmail.com |
| not complete react project | https://tahpnaras.netlify.app |

### And I will come back in the future
